@@ -188,7 +188,10 @@ class JSONWebToken:
         if audience is None:
             return
         if not (self.aud & audience):
-            raise InvalidAudience
+            raise InvalidAudience.with_detail(
+                asserted=self.aud,
+                required=list(sorted(audience))
+            )
 
     def _validate_required(self, required: set):
         missing = set()
