@@ -8,13 +8,14 @@ from ..jsonwebkeyset import JSONWebKeySet
 class JWKSLoader:
     logger: logging.Logger = logging.getLogger('uvicorn')
 
-    async def discover(self, url: str) -> JSONWebKeySet:
+    async def discover(self, url: str, timeout: int = 5) -> JSONWebKeySet:
         """Inspect the OpeID/OAuth 2.0 metadata endpoints to find the
         server ``jwks_uri`` and return a :class:`JSONWebKeySet` instance
         containing the keys.
         """
         jwks = None
-        async with aiohttp.ClientSession() as session:
+        timeout = aiohttp.ClientTimeout(total=timeout)
+        async with aiohttp.ClientSession(timeout=timeout) as session:
             metadata = (
                 await self._get(
                     session=session,
